@@ -2,13 +2,12 @@ use std::{
     intrinsics::transmute,
     io::{Read, Result},
     mem::{size_of, zeroed},
-    num::Wrapping,
     ptr::addr_of,
 };
 
 use num::{Bounded, Integer};
 
-use crate::zest_hash::zest4096;
+use crate::{counter::inc_counter, zest_hash::zest4096};
 
 // Notice: The seed of the PRNG also holds the counter, in the higher array indicies.
 // Keep your key/seed in the low bits, and the nonce after that if you wish.
@@ -44,11 +43,7 @@ impl ZestRand {
     // and sets the hash output to None
     #[inline(always)]
     pub fn next_block(&mut self) {
-        let mut carry: u64 = 1;
-        for elem in self.seed.iter_mut().rev() {
-            *elem = (Wrapping(*elem) + Wrapping(carry)).0;
-            carry = (*elem < carry) as u64;
-        }
+        inc_counter(&mut self.seed);
         self.hash_output = zest4096(self.generate_input());
     }
     // Get the current block
